@@ -11,7 +11,7 @@ class ExtractInMiddlewareSpider(scrapy.Spider):
         yield scrapy.Request(
             url="http://www.example.com",
             meta={
-                "_link_rules_": [
+                "extractor.rules": [
                     {"type": "re", "allow_domains": [], "deny_domains": []},
                     {
                         "type": "lxml",
